@@ -7,10 +7,11 @@ use Mite::Miteception;
 extends qw(Mite::Role);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.002003';
+our $VERSION   = '0.002004';
 
 use Path::Tiny;
 use mro;
+use B ();
 
 # Super classes as class names
 has extends =>
@@ -209,7 +210,7 @@ sub _compile_extends {
                             grep { !$source || !$source->has_class($_) }
                             @$extends;
 
-    my $isa_list     = join ", ", map { "q[$_]" } @$extends;
+    my $isa_list     = join ", ", map B::perlstring($_), @$extends;
 
     return <<"END";
 BEGIN {
@@ -288,10 +289,6 @@ sub _compile_buildall {
 sub _compile_destroy {
     my $self = shift;
     sprintf <<'CODE', $self->_compile_meta( '$class', '$self' );
-defined ${^GLOBAL_PHASE}
-    or eval { require Devel::GlobalDestruction; 1 }
-    or do   { *Devel::GlobalDestruction::in_global_destruction = sub { undef; } };
-
 sub DESTROY {
     my $self  = shift;
     my $class = ref( $self ) || $self;
