@@ -1,6 +1,6 @@
 {
 package Mite::Compiled;
-our $USES_MITE = q[Mite::Class];
+our $USES_MITE = "Mite::Class";
 use strict;
 use warnings;
 
@@ -13,8 +13,8 @@ sub new {
     my $no_build = delete $args->{__no_BUILD__};
 
     # Initialize attributes
-    if ( exists($args->{q[file]}) ) { my $value = do { my $to_coerce = $args->{q[file]}; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($value) and $value->isa(q[Path::Tiny]) }) or require Carp && Carp::croak(q[Type check failed in constructor: file should be Path]); $self->{q[file]} = $value;  }
-    if ( exists($args->{q[source]}) ) { (do { use Scalar::Util (); Scalar::Util::blessed($args->{q[source]}) and $args->{q[source]}->isa(q[Mite::Source]) }) or require Carp && Carp::croak(q[Type check failed in constructor: source should be InstanceOf["Mite::Source"]]); $self->{q[source]} = $args->{q[source]};  } else { require Carp; Carp::croak("Missing key in constructor: source") } require Scalar::Util && Scalar::Util::weaken($self->{q[source]});
+    if ( exists $args->{"file"} ) { my $value = do { my $to_coerce = $args->{"file"}; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($value) and $value->isa(q[Path::Tiny]) }) or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "file", "Path"); $self->{"file"} = $value;  }
+    if ( exists $args->{"source"} ) { (do { use Scalar::Util (); Scalar::Util::blessed($args->{"source"}) and $args->{"source"}->isa(q[Mite::Source]) }) or require Carp && Carp::croak(sprintf "Type check failed in constructor: %s should be %s", "source", "InstanceOf[\"Mite::Source\"]"); $self->{"source"} = $args->{"source"};  } else { require Carp; Carp::croak("Missing key in constructor: source") } require Scalar::Util && Scalar::Util::weaken($self->{"source"});
 
     # Enforce strict constructor
     my @unknown = grep not( /\A(?:file|source)\z/ ), keys %{$args}; @unknown and require Carp and Carp::croak("Unexpected keys in constructor: " . join(q[, ], sort @unknown));
@@ -25,10 +25,6 @@ sub new {
     return $self;
 }
 
-defined ${^GLOBAL_PHASE}
-    or eval { require Devel::GlobalDestruction; 1 }
-    or do   { *Devel::GlobalDestruction::in_global_destruction = sub { undef; } };
-
 sub DESTROY {
     my $self  = shift;
     my $class = ref( $self ) || $self;
@@ -50,7 +46,6 @@ sub DESTROY {
 
 sub __META__ {
     no strict 'refs';
-    require mro;
     my $class      = shift; $class = ref($class) || $class;
     my $linear_isa = mro::get_linear_isa( $class );
     return {
@@ -81,17 +76,17 @@ sub does {
 my $__XS = !$ENV{MITE_PURE_PERL} && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
 # Accessors for file
-*file = sub { @_ > 1 ? require Carp && Carp::croak("file is a read-only attribute of @{[ref $_[0]]}") : ( exists($_[0]{q[file]}) ? $_[0]{q[file]} : ( $_[0]{q[file]} = do { my $default_value = do { my $to_coerce = do { my $method = $Mite::Compiled::__file_DEFAULT__; $_[0]->$method }; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($default_value) and $default_value->isa(q[Path::Tiny]) }) or do { require Carp; Carp::croak(q[Type check failed in default: file should be Path]) }; $default_value } ) ) };
+sub file { @_ > 1 ? require Carp && Carp::croak("file is a read-only attribute of @{[ref $_[0]]}") : ( exists($_[0]{"file"}) ? $_[0]{"file"} : ( $_[0]{"file"} = do { my $default_value = do { my $to_coerce = do { my $method = $Mite::Compiled::__file_DEFAULT__; $_[0]->$method }; ((do { use Scalar::Util (); Scalar::Util::blessed($to_coerce) and $to_coerce->isa(q[Path::Tiny]) })) ? $to_coerce : (do { package Mite::Miteception; defined($to_coerce) and do { ref(\$to_coerce) eq 'SCALAR' or ref(\(my $val = $to_coerce)) eq 'SCALAR' } }) ? scalar(do { local $_ = $to_coerce; Path::Tiny::path($_) }) : $to_coerce }; (do { use Scalar::Util (); Scalar::Util::blessed($default_value) and $default_value->isa(q[Path::Tiny]) }) or do { require Carp; Carp::croak(sprintf "Type check failed in default: %s should be %s", "file", "Path") }; $default_value } ) ) }
 
 # Accessors for source
 if ( $__XS ) {
     Class::XSAccessor->import(
         chained => 1,
-        getters => { q[source] => q[source] },
+        "getters" => { "source" => "source" },
     );
 }
 else {
-    *source = sub { @_ > 1 ? require Carp && Carp::croak("source is a read-only attribute of @{[ref $_[0]]}") : $_[0]{q[source]} };
+    *source = sub { @_ > 1 ? require Carp && Carp::croak("source is a read-only attribute of @{[ref $_[0]]}") : $_[0]{"source"} };
 }
 
 
