@@ -1,4 +1,4 @@
-use 5.010001;
+use 5.008001;
 use strict;
 use warnings;
 
@@ -10,6 +10,20 @@ package Mite::Shim;
 use strict;
 use warnings;
 
+if ( $] < 5.009005 ) {
+    require MRO::Compat;
+}
+else {
+    require mro;
+}
+
+defined ${^GLOBAL_PHASE}
+or eval { require Devel::GlobalDestruction; 1 }
+or do {
+    warn "WARNING: Devel::GlobalDestruction recommended!\n";
+    *Devel::GlobalDestruction::in_global_destruction = sub { undef; };
+};
+
 sub _is_compiling {
     return $ENV{MITE_COMPILE} ? 1 : 0;
 }
